==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/iotoperationsorchestrator/kotlin/inputs/TopologiesPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.iotoperationsorchestrator.kotlin.inputs

import com.pulumi.azurenative.iotoperationsorchestrator.inputs.TopologiesPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Defines a desired runtime component.
 * @property bindings bindings description.
 */
public data class TopologiesPropertiesArgs(
    public val bindings: Output<List<BindingPropertiesArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.iotoperationsorchestrator.inputs.TopologiesPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.iotoperationsorchestrator.inputs.TopologiesPropertiesArgs =
        com.pulumi.azurenative.iotoperationsorchestrator.inputs.TopologiesPropertiesArgs.builder()
            .bindings(
                bindings?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [TopologiesPropertiesArgs].
 */
@PulumiTagMarker
public class TopologiesPropertiesArgsBuilder internal constructor() {
    private var bindings: Output<List<BindingPropertiesArgs>>? = null

    /**
     * @param value bindings description.
     */
    @JvmName("otusnggahfiqhfmk")
    public suspend fun bindings(`value`: Output<List<BindingPropertiesArgs>>) {
        this.bindings = value
    }

    @JvmName("rctvvytpbyiepjmj")
    public suspend fun bindings(vararg values: Output<BindingPropertiesArgs>) {
        this.bindings = Output.all(values.asList())
    }

    /**
     * @param values bindings description.
     */
    @JvmName("jgxamlclgofclfuu")
    public suspend fun bindings(values: List<Output<BindingPropertiesArgs>>) {
        this.bindings = Output.all(values)
    }

    /**
     * @param value bindings description.
     */
    @JvmName("vlspbbywaomkrwct")
    public suspend fun bindings(`value`: List<BindingPropertiesArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.bindings = mapped
    }

    /**
     * @param argument bindings description.
     */
    @JvmName("ympijyyvhkjsqycj")
    public suspend fun bindings(argument: List<suspend BindingPropertiesArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            BindingPropertiesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.bindings = mapped
    }

    /**
     * @param argument bindings description.
     */
    @JvmName("acxrejwpuytegoec")
    public suspend fun bindings(vararg argument: suspend BindingPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            BindingPropertiesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.bindings = mapped
    }

    /**
     * @param argument bindings description.
     */
    @JvmName("xakoecyshkttwxxq")
    public suspend fun bindings(argument: suspend BindingPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(BindingPropertiesArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.bindings = mapped
    }

    /**
     * @param values bindings description.
     */
    @JvmName("awylwllhsjmeifao")
    public suspend fun bindings(vararg values: BindingPropertiesArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.bindings = mapped
    }

    internal fun build(): TopologiesPropertiesArgs = TopologiesPropertiesArgs(
        bindings = bindings,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/iotoperationsorchestrator/kotlin/inputs/TopologiesPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.iotoperationsorchestrator.kotlin.inputs

import com.pulumi.azurenative.iotoperationsorchestrator.inputs.TopologiesPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Defines a desired runtime component.
 * @property bindings bindings description.
 */
public data class TopologiesPropertiesArgs(
    public val bindings: Output<List<BindingPropertiesArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.iotoperationsorchestrator.inputs.TopologiesPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.iotoperationsorchestrator.inputs.TopologiesPropertiesArgs =
        com.pulumi.azurenative.iotoperationsorchestrator.inputs.TopologiesPropertiesArgs.builder()
            .bindings(
                bindings?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [TopologiesPropertiesArgs].
 */
@PulumiTagMarker
public class TopologiesPropertiesArgsBuilder internal constructor() {
    private var bindings: Output<List<BindingPropertiesArgs>>? = null

    /**
     * @param value bindings description.
     */
    @JvmName("cfiuqvnurwjpusdw")
    public suspend fun bindings(`value`: Output<List<BindingPropertiesArgs>>) {
        this.bindings = value
    }

    @JvmName("ryvgkjnneurwfecp")
    public suspend fun bindings(vararg values: Output<BindingPropertiesArgs>) {
        this.bindings = Output.all(values.asList())
    }

    /**
     * @param values bindings description.
     */
    @JvmName("tsvuqgyofkhtghfj")
    public suspend fun bindings(values: List<Output<BindingPropertiesArgs>>) {
        this.bindings = Output.all(values)
    }

    /**
     * @param value bindings description.
     */
    @JvmName("lxykvphdstkahtbk")
    public suspend fun bindings(`value`: List<BindingPropertiesArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.bindings = mapped
    }

    /**
     * @param argument bindings description.
     */
    @JvmName("nunhccvjhysghwyc")
    public suspend fun bindings(argument: List<suspend BindingPropertiesArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            BindingPropertiesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.bindings = mapped
    }

    /**
     * @param argument bindings description.
     */
    @JvmName("nmdgmckxvkopfipf")
    public suspend fun bindings(vararg argument: suspend BindingPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            BindingPropertiesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.bindings = mapped
    }

    /**
     * @param argument bindings description.
     */
    @JvmName("litgwaqnvwntakws")
    public suspend fun bindings(argument: suspend BindingPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(BindingPropertiesArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.bindings = mapped
    }

    /**
     * @param values bindings description.
     */
    @JvmName("pcsciyeocoqwstnf")
    public suspend fun bindings(vararg values: BindingPropertiesArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.bindings = mapped
    }

    internal fun build(): TopologiesPropertiesArgs = TopologiesPropertiesArgs(
        bindings = bindings,
    )
}
